import sys
import signal
signal.signal(signal.SIGPIPE, signal.SIG_DFL)
#===============================================================================
#
#    $score                  = score_init_site(   $seq, $init_pos );
#    $score                  = score_init_site(  \$seq, $init_pos );
#
#  ( $score, $cdn_scr, $codon, $rbs_scr, $rbs, $offset ) = score_init_site(  $seq, $init_pos );
#  ( $score, $cdn_scr, $codon, $rbs_scr, $rbs, $offset ) = score_init_site( \$seq, $init_pos );
#
#    $score                  = score_init_codon(  $seq, $init_pos );
#    $score                  = score_init_codon( \$seq, $init_pos );
#  ( $score, $codon )        = score_init_codon(  $seq, $init_pos );
#  ( $score, $codon )        = score_init_codon( \$seq, $init_pos );
#
#    $score                  = score_init_rbs(    $seq, $init_pos );
#    $score                  = score_init_rbs(   \$seq, $init_pos );
#  ( $score, $rbs, $offset ) = score_init_rbs(    $seq, $init_pos );
#  ( $score, $rbs, $offset ) = score_init_rbs(   \$seq, $init_pos );
#
#    $seq      is the DNA sequence containing the initiation site to be evaluated
#    $init_pos is the 1-base position of the initiator codon in $seq
#
#  The two required parameters can be followed by \%init_scr and/or \@rbs_scr,
#  as appropriate for the function.
#
#    $score    is the initiator and/or RBS bit score, or undef if not an initiator
#    $codon    is the initiator codon, or undef if not an initiator
#    $rbs      is the highest scoring RBS sequence, or undef if none is found.
#    $offset   is the left-most position of the RBS relative to the initiator,
#                  of undef if none is found.
#
#  Input sequence should be at least 21 nt, including the initiator codon
#
#                    $init_pos (1-based position of initiator codon in $seq)
#                        |
#          -13      -4   0 2   offsets from $init_pos
#           |        |   | |
#  ---------+--------+---ntn-------
#        ----
#       -----
#      ------
#   left-most RBS
#    candidates
#
#  Returned score should be tested for defined, as a value of 0.0 is possible.
#
#===============================================================================
def main(seq, offset):
	"""This is so the package can be called on the command line for testing"""
	rbs = ScoreXlationInit()
	s = rbs.score_init_site(seq, offset)
	sys.stdout.write(str(s[0]))
	sys.stdout.write("\n")



def pairwise(iterable):
	a = iter(iterable)
	return zip(a,a)

class ScoreXlationInit():
	def __init__(self):
		#  We store RBS sequence scores with a separate hash at each offset
		#
		#               Scores at offsets from start of initiator
		#                -4  -5  -6  -7  -8  -9 -10 -11 -12 -13
		self.rbs_scr = [ {}, {}, {}, {}, {}, {}, {}, {}, {}, {} ]

		#  There might be reasons to adjust this initiator score to be more permissive
		#  of rare initiators.
		self.min_init_scr = -12.0;

		#  A hash of initiator codon scores.  Keys are lower-case DNA nucleotides
		#
		#  Observed initiator codon counts in CoreSEED
		#
		#   2476865  atg    0.00
		#    500243  gtg   -2.31
		#    274258  ttg   -3.17
		#       826  ctg  -11.55
		#       463  att  -12.39
		#       273  ata  -13.15
		#       125  atc  -14.27
		#
		self.init_scr = { 'atg' :   0.0,  # This must be tested for defined(), not false
						  'gtg' :  -2.3,
						  'ttg' :  -3.2,
						  'ctg' : -11.6,
						  'att' : -12.4,
						  'ata' : -13.2,
						  'atc' : -14.3
						}

		for key in self.init_scr:
			if self.init_scr[key] < self.min_init_scr: self.init_scr[key] = self.min_init_scr

		#  Minimum occurrence of candidate RBS sequences in 3,254,479 initiation sites
		#  in CoreSEED

		self.min_max_cnt =  5000;  # Min count at most abundant offset
		self.min_ttl_cnt = 30000;  # Min count summed over all 10 offsets

		#  Minimum score for an RBS to be included (max score over all 10 offsets)

		self.min_max_scr =   2.5;

		#  Minimum position-specific score:

		self.min_scr     =    1.0;

		#  Possible adjustment to raw scores is currently set to 0.0, since the
		#  raw score seems to be a remarkably good reflection of the relative
		#  frequency of that score in an RBS versus a non-RBS context:
		#
		#  info. is the log-base 2 frequency of the given score or higher being
		#  observed in an RBS context relative to a non-RBS context.
		#
		#  Distribution of maximal RBS scores 
		#
		#               RBS            non-RBS
		#   raw    ------------     ------------
		#  score   count  cumu.     count  cumu.    info.
		#  ----------------------------------------------
		#   6.3    42879  0.013       550  0.000     6.3
		#   6.2    26420  0.021       481  0.000     6.1
		#   6.1    43328  0.035       577  0.000     6.1
		#   6.0    39860  0.047       619  0.001     6.1
		#   5.9    32482  0.057       625  0.001     6.0
		#   5.8    12989  0.061       298  0.001     6.0
		#   5.7    49529  0.076      1304  0.001     5.8
		#   5.6    30403  0.085       877  0.002     5.7
		#   5.5    33681  0.096      1260  0.002     5.6
		#   5.4    62547  0.115      2186  0.003     5.4
		#   5.3    27581  0.123      1037  0.003     5.4
		#   5.2    51415  0.139      2055  0.004     5.3
		#   5.1    10885  0.143       479  0.004     5.2
		#   4.9    60928  0.161      3474  0.005     5.1
		#   4.8    68572  0.182      4860  0.006     4.8
		#   4.7    52915  0.199      3730  0.008     4.7
		#   4.6    35822  0.210      2972  0.008     4.6
		#   4.5   106690  0.242      8893  0.011     4.4
		#   4.4    55563  0.259      5965  0.013     4.3
		#   4.3    86550  0.286      9271  0.016     4.2
		#   4.2    57648  0.304      8088  0.018     4.1
		#   4.1    39555  0.316      6056  0.020     4.0
		#   4.0    50748  0.332      7325  0.022     3.9
		#   3.9    47919  0.346      8372  0.025     3.8
		#   3.8    68696  0.367     18492  0.031     3.6
		#   3.7    31787  0.377      5868  0.032     3.5
		#   3.6    49854  0.392     10975  0.036     3.5
		#   3.5    35415  0.403      7056  0.038     3.4
		#   3.4    32974  0.413      8152  0.041     3.4
		#   3.3    42670  0.427     14253  0.045     3.2
		#   3.2    62668  0.446     26235  0.053     3.1
		#   3.1    45339  0.460     17870  0.058     3.0
		#   3.0    39043  0.472     14123  0.063     2.9
		#   2.9    25871  0.480     12715  0.067     2.8
		#   2.8    26593  0.488     10588  0.070     2.8
		#   2.7    50780  0.503     29416  0.079     2.7
		#   2.6    52958  0.520     30257  0.088     2.6
		#   2.5    41651  0.533     28575  0.097     2.5
		#   2.4    28770  0.541     18715  0.103     2.4
		#   2.3    26455  0.550     20662  0.109     2.3
		#   2.2    24122  0.557     20546  0.116     2.3
		#   2.1    28301  0.566     23685  0.123     2.2
		#   2.0    25797  0.574     24176  0.130     2.1
		#   1.9    19390  0.580     16842  0.135     2.1
		#   1.8    21562  0.586     22537  0.142     2.0
		#   1.7     8750  0.589      7861  0.145     2.0
		#   1.6    10604  0.592      9969  0.148     2.0
		#   1.5    21378  0.599     22033  0.155     2.0
		#   1.4    15136  0.603     17781  0.160     1.9
		#   1.3    10585  0.607     12507  0.164     1.9
		#   1.2    11341  0.610     15992  0.169     1.9
		#   1.1     8967  0.613     12488  0.173     1.8
		#   1.0    14807  0.617     20852  0.179     1.8
		#   0.0  1245306  1.000   2671198  1.000     0.0
		#  ----------------------------------------------
		
		self.scr_adjust  =     0.0;

		self._load_data()


	def score_init_site(self, seqR, init_pos, init_scr=None, rbs_scr=None):
		"""Returns a score for an RBS site

		The two required parameters can be followed by init_scr and/or rbs_scr,
		as appropriate for the function.

		  score, cdn_scr, codon, rbs_scr, rbs, offset  = score_init_site(  seq, init_pos )

		  score    is the initiator and/or RBS bit score, or undef if not an initiator
		  codon    is the initiator codon, or undef if not an initiator
		  rbs      is the highest scoring RBS sequence, or undef if none is found.
		  offset   is the left-most position of the RBS relative to the initiator,
		                of undef if none is found.

		Input sequence should be at least 21 nt, including the initiator codon

		                  $init_pos (1-based position of initiator codon in $seq)
		                      |
		        -13      -4   0 2   offsets from $init_pos
		         |        |   | |
		---------+--------+---ntn-------
		      ----
		     -----
		    ------
		 left-most RBS
		  candidates

		Returned score should be tested for defined, as a value of 0.0 is possible.
		"""
		
		cdn_scr, codon  = self.score_init_codon( seqR, init_pos )
		#$codon or return ();

		rbs_scr, rbs, offset  = self.score_init_rbs( seqR, init_pos )

		score = round(cdn_scr + rbs_scr, 1)

		#wantarray ? ( $score, $cdn_scr, $codon, $rbs_scr, $rbs, $offset ) : $score;
		return score, cdn_scr, codon, rbs_scr, rbs, offset

	def score_init_codon(self, seqR, init_pos):
		"""Returns the start codon score"""
		#$seqR && $init_pos
		#    or return ();
		#$scores ||= \%init_scr;

		#length( $$seqR ) >= $init_pos + 2
		#or return ();
		init = seqR[ init_pos-1 : init_pos+2 ].lower()
		if not init: raise ValueError('Start codon not found at index')

		#wantarray ? ( defined $scr ? ( $scr, $init ) : ( undef, undef ) ) : $scr;
		return self.init_scr[init], init


	def score_init_rbs(self, seqR, init_pos):
		"""Returns the rbs score"""
		best = [ 0, None, None ]

		for i in range(-4, -14, -1):
			n_avail = init_pos + i
			l_max   = min( n_avail, 6 )
			for l in range(4, l_max+1):
				rbs = seqR[n_avail - l : n_avail ].lower()
				try:
					s   = self.rbs_scr[ -i - 4 ][ rbs ]
				except KeyError:
					continue
				if s > best[0]: best = [ s, rbs, i ]

		best[0] = round(best[0], 1)
		#wantarray ? @$best : $best->[0];
		return best


	def _load_data(self):
		"""Load the rbs score data"""
		for line in __DATA__.split('\n'):
			seq, bkg, max, _, *data = line.split()
			
			if not float(max) >= self.min_max_scr: continue

			ttl_cnt = 0
			max_cnt = 0
			scrs = []
			for cnt, scr in pairwise(map(float,data)):
				scrs.append( scr )
				ttl_cnt += cnt
				if cnt > max_cnt:
					max_cnt  = cnt

			if ttl_cnt < self.min_ttl_cnt or max_cnt < self.min_max_cnt: continue

			#  Scores are read from DATA block with offsets -13 to -4.
			#  They are recorded here in order -4 to -13.
			for i in range(0, 10):
				scr = scrs[i];
				if scr >= self.min_scr: self.rbs_scr[ 9 - i ][ seq ] = scr  


#
#  The data for the position-specific RBS sequence scores
#
#                                                                        offset from first base of the initiator codon
#                          ------------------------------------------------------------------------------------------------------------------------------------------
#                              -13           -12           -11           -10            -9            -8            -7            -6            -5            -4
#  seq      bkg    max     ------------  ------------  ------------  ------------  ------------  ------------  ------------  ------------  ------------  ------------
#          count  score    count  score  count  score  count  score  count  score  count  score  count  score  count  score  count  score  count  score  count  score     
__DATA__ = """\
  aggagg     549   6.3 |    2874   2.4    5298   3.3   12304   4.5   20627   5.2   32482   5.9   42879   6.3   27949   5.7   23902   5.4   16170   4.9    1645   1.6
  aaggag     618   6.2 |    5179   3.1   11163   4.2   20807   5.1   31235   5.7   45408   6.2   43328   6.1   39860   6.0   26928   5.4    4247   2.8    1078   0.8
  ggaggt     444   5.8 |    1083   1.3    1887   2.1    3015   2.8    7496   4.1   13101   4.9   17875   5.3   24337   5.8   17553   5.3   12363   4.8    5699   3.7
  aggaga     653   5.7 |    1787   1.5    3041   2.2    5876   3.2    9854   3.9   15742   4.6   26066   5.3   31390   5.6   33263   5.7   19521   4.9    4787   2.9
  ggagga     644   5.6 |    1915   1.6    2955   2.2    4968   2.9   10582   4.0   16417   4.7   24838   5.3   31316   5.6   19872   4.9   17357   4.8   12481   4.3
  taggag     290   5.5 |    1820   2.6    2972   3.4    5456   4.2   10945   5.2   11703   5.3   10690   5.2   13212   5.5    6475   4.5    1025   1.8     440   0.6
   aggag    2154   5.5 |   11677   2.4   24056   3.5   40375   4.2   63793   4.9   94215   5.5   88676   5.4   89651   5.4   60826   4.8   12667   2.6    5622   1.4
  aggagt     425   5.3 |    1008   1.2    1852   2.1    3196   2.9    5725   3.8    9214   4.4   14295   5.1   15546   5.2   17137   5.3   13135   4.9    2836   2.7
   ggagg    2327   5.2 |    7878   1.8   12737   2.5   28026   3.6   44656   4.3   64824   4.8   87983   5.2   59077   4.7   50533   4.4   34025   3.9    4120   0.8
  gaggtg     573   5.2 |     574   0.0    1366   1.3    1914   1.7    2862   2.3    7465   3.7   11928   4.4   15747   4.8   21456   5.2   11555   4.3    3695   2.7
  gaggag     666   5.0 |    2400   1.8    5514   3.0    7598   3.5   11392   4.1   20988   5.0   18234   4.8   18966   4.8   16923   4.7    6022   3.2    3364   2.3
  ggaggg     561   5.0 |    1137   1.0    1828   1.7    2878   2.4    5698   3.3    8967   4.0   13732   4.6   17489   5.0    9427   4.1    8001   3.8    5746   3.4
  aaagga    1006   4.9 |    7816   3.0   14065   3.8   20520   4.4   28070   4.8   29448   4.9   28575   4.8   22882   4.5    8312   3.0    1897   0.9    1037   0.0
  aggagc     530   4.9 |     883   0.7    1486   1.5    2680   2.3    4169   3.0    6355   3.6   10975   4.4   13791   4.7   15349   4.9   12000   4.5    3399   2.7
  gaggta     366   4.8 |     432   0.2     714   1.0    1150   1.7    1609   2.1    3080   3.1    5994   4.0    8164   4.5   10095   4.8    8165   4.5    5908   4.0
  ggagaa     849   4.7 |    1395   0.7    1575   0.9    2242   1.4    3905   2.2    6161   2.9    9267   3.4   16124   4.2   22697   4.7   20982   4.6   11832   3.8
  gaggaa     810   4.7 |    1605   1.0    2275   1.5    2690   1.7    3921   2.3    7325   3.2   11484   3.8   18242   4.5   21221   4.7   11748   3.9   10069   3.6
  taagga     608   4.7 |    4162   2.8    5631   3.2    9051   3.9   14820   4.6   12729   4.4   15219   4.6   15625   4.7    3061   2.3     910   0.6     730   0.3
  ggagac     460   4.7 |     525   0.2     488   0.1     994   1.1    1891   2.0    2758   2.6    4695   3.4    8110   4.1   10467   4.5   11586   4.7    7086   3.9
  aggtga     600   4.7 |     827   0.5     718   0.3    1348   1.2    1944   1.7    2255   1.9    5264   3.1   10508   4.1   12391   4.4   15090   4.7    5567   3.2
  agggag     481   4.6 |    1859   2.0    3476   2.9    6019   3.6    9024   4.2   11801   4.6   11355   4.6   10504   4.4    7003   3.9    3390   2.8    1305   1.4
   gaggt    1891   4.6 |    3350   0.8    4478   1.2    6969   1.9   15256   3.0   24294   3.7   34160   4.2   45525   4.6   31618   4.1   22399   3.6    9046   2.3
  aggggg     517   4.5 |    1104   1.1    1906   1.9    3393   2.7    5882   3.5    9017   4.1   12053   4.5    6938   3.7    5575   3.4    4723   3.2     899   0.8
   ggaga    2454   4.5 |    5016   1.0    7167   1.5   12695   2.4   19163   3.0   27954   3.5   46394   4.2   55753   4.5   55309   4.5   31842   3.7    9338   1.9
   aagga    3086   4.5 |   19369   2.6   30786   3.3   44458   3.8   66232   4.4   68942   4.5   70107   4.5   59944   4.3   18338   2.6    5388   0.8    3754   0.3
  gaggga     494   4.5 |    1287   1.4    1977   2.0    2729   2.5    3794   2.9    5474   3.5    7228   3.9    9942   4.3   10982   4.5    5589   3.5    3616   2.9
   gagga    2517   4.5 |    9722   1.9   12506   2.3   19268   2.9   35481   3.8   39658   4.0   53597   4.4   55204   4.5   30563   3.6   26301   3.4   16925   2.7
  ggagtg     403   4.4 |     483   0.3     867   1.1    1364   1.8    2000   2.3    4047   3.3    6260   4.0    8597   4.4    7947   4.3    6290   4.0    3929   3.3
  ggaggc     701   4.4 |     876   0.3    1208   0.8    1876   1.4    4250   2.6    6171   3.1    8379   3.6   14841   4.4   12225   4.1   12812   4.2   10099   3.8
  gaaagg     729   4.4 |    6970   3.3   10714   3.9   14196   4.3   15018   4.4   14089   4.3   11339   4.0    5769   3.0    2013   1.5    1093   0.6    1140   0.6
  ggagta     410   4.3 |     533   0.4     668   0.7    1122   1.5    1410   1.8    2313   2.5    4011   3.3    5560   3.8    7109   4.1    8278   4.3    5489   3.7
    ggag    8950   4.3 |   27912   1.6   53787   2.6   83244   3.2  121716   3.8  180619   4.3  168525   4.2  162622   4.2  109302   3.6   26445   1.6   14279   0.7
  ggagag     571   4.3 |    1443   1.3    2088   1.9    2677   2.2    4151   2.9    5992   3.4    7603   3.7   10789   4.2   11507   4.3   10717   4.2    6041   3.4
  aagggg     602   4.3 |    2027   1.8    3680   2.6    6295   3.4    8781   3.9   12031   4.3    9379   4.0    7134   3.6    5178   3.1    1313   1.1     646   0.1
  ggagat     611   4.3 |     706   0.2     865   0.5    1254   1.0    2748   2.2    4252   2.8    6389   3.4   11371   4.2   11082   4.2   12024   4.3    6883   3.5
  gaggtt     518   4.1 |     542   0.1     772   0.6     889   0.8    1581   1.6    3122   2.6    4289   3.0    7142   3.8    9171   4.1    7570   3.9    7976   3.9
   ggagt    1670   4.1 |    2642   0.7    4074   1.3    6498   2.0   10684   2.7   16523   3.3   24807   3.9   27496   4.0   29154   4.1   21967   3.7    5811   1.8
    agga    9975   4.1 |   42924   2.1   61618   2.6   93063   3.2  139185   3.8  147285   3.9  169928   4.1  143075   3.8   56551   2.5   36581   1.9   24757   1.3
  gaggat     601   4.1 |     831   0.5    1021   0.8    1269   1.1    2349   2.0    4306   2.8    6022   3.3   10190   4.1    9971   4.1    7674   3.7    6935   3.5
  ggggga     578   4.1 |    1110   0.9    1371   1.2    2166   1.9    3311   2.5    4763   3.0    7468   3.7    9785   4.1    7048   3.6    4659   3.0    3727   2.7
  ggagtt     540   4.1 |     611   0.2     753   0.5    1057   1.0    2103   2.0    3024   2.5    4227   3.0    6917   3.7    7806   3.9    9029   4.1    7197   3.7
  ggagtc     340   4.0 |     289  -0.2     354   0.1     531   0.6     985   1.5    1300   1.9    2025   2.6    3733   3.5    4634   3.8    5557   4.0    5352   4.0
  gggaga     604   4.0 |    1082   0.8    1403   1.2    2377   2.0    3540   2.6    5164   3.1    7582   3.6    9865   4.0    9347   4.0    5615   3.2    3004   2.3
    gagg    9272   4.0 |   27050   1.5   40532   2.1   74293   3.0   92270   3.3  127073   3.8  148889   4.0   94020   3.3   80871   3.1   48225   2.4   12410   0.4
   aggtg    2157   4.0 |    2216   0.0    4285   1.0    5394   1.3    7051   1.7   14335   2.7   20145   3.2   25144   3.5   33973   4.0   16369   2.9    4908   1.2
  aggaat     809   3.9 |    1057   0.4    1197   0.6    1568   1.0    2106   1.4    3123   1.9    5097   2.7    7976   3.3   10982   3.8   12038   3.9    5519   2.8
  gagagg     517   3.9 |    2297   2.2    3497   2.8    5394   3.4    6484   3.6    7621   3.9    6849   3.7    5077   3.3    4790   3.2    3016   2.5    2346   2.2
  ggagca     606   3.8 |     710   0.2     768   0.3    1234   1.0    1881   1.6    2452   2.0    3465   2.5    6680   3.5    8635   3.8    8704   3.8    6719   3.5
   gggag    2212   3.8 |    5917   1.4   10068   2.2   16128   2.9   23572   3.4   31025   3.8   31239   3.8   29435   3.7   20164   3.2    8468   1.9    4317   1.0
  aggtgt     462   3.8 |     367  -0.3     411  -0.2     624   0.4     791   0.8    1303   1.5    2465   2.4    3458   2.9    5232   3.5    6458   3.8    3720   3.0
  gggggt     433   3.8 |     523   0.3     702   0.7     767   0.8    1676   2.0    2924   2.8    3662   3.1    5913   3.8    3401   3.0    2493   2.5    1890   2.1
  aggaaa    1241   3.8 |    2835   1.2    3007   1.3    3453   1.5    3725   1.6    4727   1.9    7273   2.6   10238   3.0   16424   3.7   16842   3.8    7750   2.6
  aggtgg     522   3.8 |     746   0.5     769   0.6    1711   1.7    2050   2.0    2587   2.3    4576   3.1    3866   2.9    4853   3.2    7038   3.8    2650   2.3
  ggagcc     595   3.7 |     536  -0.2     538  -0.1     704   0.2    1195   1.0    1747   1.6    2772   2.2    4786   3.0    6704   3.5    7770   3.7    5701   3.3
  gaggac     548   3.7 |     685   0.3     912   0.7     949   0.8    1606   1.6    2862   2.4    3918   2.8    6199   3.5    7089   3.7    5119   3.2    5933   3.4
   aaagg    3455   3.7 |   23325   2.8   32546   3.2   42948   3.6   44594   3.7   42660   3.6   36148   3.4   16526   2.3    4989   0.5    3178  -0.1    3214  -0.1
  aggaac     595   3.7 |     657   0.1     855   0.5    1095   0.9    1344   1.2    2073   1.8    3777   2.7    5027   3.1    6362   3.4    7619   3.7    4032   2.8
  ggtgat     746   3.7 |     569  -0.4     579  -0.4     461  -0.7     775   0.1     942   0.3    1075   0.5    2993   2.0    5831   3.0    6778   3.2    9445   3.7
   aggaa    3465   3.7 |    8358   1.3   10633   1.6   11990   1.8   15555   2.2   23487   2.8   30180   3.1   40538   3.5   43864   3.7   20938   2.6   13730   2.0
  agggga     566   3.7 |    1302   1.2    1947   1.8    3162   2.5    4286   2.9    5163   3.2    7160   3.7    6949   3.6    6539   3.5    4618   3.0    1634   1.5
   gaggg    2115   3.6 |    5316   1.3    6750   1.7    9879   2.2   15859   2.9   18593   3.1   25416   3.6   26369   3.6   14215   2.7   12619   2.6    8527   2.0
   agagg    2095   3.6 |    7994   1.9   11088   2.4   17857   3.1   21262   3.3   25243   3.6   23301   3.5   16049   2.9   13004   2.6    6011   1.5    3813   0.9
  aaaggg     738   3.6 |    3236   2.1    5419   2.9    7623   3.4    8884   3.6    8637   3.5    6755   3.2    4569   2.6    2317   1.7     903   0.3     652  -0.2
  aaggat     814   3.6 |    1508   0.9    2262   1.5    2732   1.7    3908   2.3    6073   2.9    7679   3.2    9446   3.5    9767   3.6    4472   2.5    1273   0.6
  gggagt     405   3.6 |     564   0.5     900   1.2    1239   1.6    2027   2.3    3094   2.9    4043   3.3    4851   3.6    4535   3.5    3663   3.2    1913   2.2
   agggg    2122   3.6 |    5286   1.3    8395   2.0   12916   2.6   18278   3.1   25068   3.6   20706   3.3   18578   3.1   15078   2.8    5357   1.3    3955   0.9
  ggggag     628   3.6 |    1467   1.2    2388   1.9    3315   2.4    5187   3.0    7409   3.6    6549   3.4    7267   3.5    6252   3.3    3401   2.4    1940   1.6
  gagggt     408   3.5 |     479   0.2     601   0.6     640   0.6    1147   1.5    2180   2.4    2835   2.8    4737   3.5    4442   3.4    2782   2.8    2886   2.8
  agggat     519   3.5 |     626   0.3     759   0.5     887   0.8    1255   1.3    1808   1.8    2426   2.2    3606   2.8    5211   3.3    5849   3.5    3228   2.6
  gtgagg     475   3.5 |    1106   1.2    1905   2.0    3166   2.7    3066   2.7    5348   3.5    5100   3.4    2638   2.5    3218   2.8    2131   2.2    1357   1.5
   ggagc    2459   3.5 |    2759   0.2    3934   0.7    6568   1.4    8741   1.8   12415   2.3   21435   3.1   26199   3.4   27626   3.5   21468   3.1    7176   1.5
  aaggga     648   3.5 |    2416   1.9    4067   2.6    5890   3.2    7164   3.5    7275   3.5    7166   3.5    5850   3.2    4208   2.7    2054   1.7     773   0.3
  aaggac     554   3.5 |     801   0.5    1369   1.3    1663   1.6    2173   2.0    3696   2.7    4813   3.1    5495   3.3    6209   3.5    2783   2.3    1060   0.9
  ggggaa     702   3.5 |    1068   0.6    1198   0.8    1390   1.0    1800   1.4    2389   1.8    3788   2.4    6160   3.1    7849   3.5    5665   3.0    3952   2.5
  ggaagg     662   3.5 |    3464   2.4    4210   2.7    5610   3.1    7348   3.5    6611   3.3    6171   3.2    4379   2.7    2499   1.9    2148   1.7    1912   1.5
   taagg    2148   3.5 |    9464   2.1   14079   2.7   22046   3.4   18358   3.1   21668   3.3   23614   3.5    5620   1.4    2220   0.0    1948  -0.1    1761  -0.3
  gagggg     607   3.5 |    1309   1.1    2069   1.8    2745   2.2    3870   2.7    6342   3.4    5992   3.3    6307   3.4    6660   3.5    3167   2.4    2541   2.1
  gaggca     568   3.4 |     607   0.1     813   0.5    1033   0.9    1122   1.0    1904   1.7    2797   2.3    3931   2.8    6201   3.4    5137   3.2    5419   3.3
  ggggtg     610   3.4 |     513  -0.2     839   0.5     929   0.6    1122   0.9    2384   2.0    3732   2.6    4358   2.8    6609   3.4    3249   2.4    1325   1.1
  gagtga     491   3.4 |     870   0.8     671   0.5    1148   1.2    1367   1.5    1247   1.3    2678   2.4    4251   3.1    5280   3.4    5056   3.4    3633   2.9
  gagaga     615   3.4 |    1229   1.0    1498   1.3    1619   1.4    1942   1.7    2630   2.1    3509   2.5    4866   3.0    6600   3.4    5876   3.3    5361   3.1
  aggggt     413   3.4 |     521   0.3     758   0.9    1024   1.3    1742   2.1    2756   2.7    3847   3.2    4427   3.4    3926   3.2    3308   3.0    1509   1.9
   ggggg    2226   3.4 |    3536   0.7    4874   1.1    8041   1.9   12295   2.5   17618   3.0   23858   3.4   16173   2.9   12153   2.4    9831   2.1    3279   0.6
  aggata     750   3.4 |     939   0.3    1107   0.6    1433   0.9    1454   1.0    1958   1.4    3604   2.3    4490   2.6    7977   3.4    7416   3.3    4439   2.6
  taaggg     444   3.4 |    1828   2.0    2281   2.4    3410   2.9    4682   3.4    3172   2.8    3329   2.9    3085   2.8     755   0.8     406  -0.1     398  -0.2
   aggga    2067   3.4 |    6314   1.6    9540   2.2   13154   2.7   17201   3.1   18772   3.2   20694   3.3   21143   3.4   17534   3.1    8890   2.1    5346   1.4
  aggaca     544   3.3 |     667   0.3     829   0.6    1013   0.9    1044   0.9    1519   1.5    2499   2.2    3568   2.7    5539   3.3    5043   3.2    2803   2.4
  gagaca     475   3.3 |     558   0.2     646   0.4     531   0.2     675   0.5    1026   1.1    1198   1.3    2084   2.1    3641   2.9    4390   3.2    4748   3.3
  aggatg     656   3.3 |     595  -0.1    1187   0.9    1707   1.4    1839   1.5    3187   2.3    4553   2.8    4986   2.9    6490   3.3    4703   2.8    2227   1.8
  aggtgc     548   3.3 |     398  -0.5     318  -0.8     602   0.1     609   0.2     906   0.7    2030   1.9    2313   2.1    2668   2.3    5387   3.3    4432   3.0
  ggtgaa     833   3.3 |     961   0.2    1004   0.3     760  -0.1    1221   0.6    1312   0.7    1479   0.8    3748   2.2    6658   3.0    7098   3.1    8175   3.3
  ggagct     470   3.3 |     489   0.1     514   0.1     743   0.7    1356   1.5    1743   1.9    2403   2.4    4195   3.2    4396   3.2    4588   3.3    3627   2.9
  gggggg     438   3.3 |     637   0.5     771   0.8    1161   1.4    1893   2.1    2890   2.7    3894   3.2    4249   3.3    2718   2.6    2017   2.2    1328   1.6
   ggtga    2737   3.3 |    3225   0.2    2616  -0.1    4250   0.6    4591   0.7    4568   0.7   10985   2.0   18717   2.8   20271   2.9   26473   3.3    9955   1.9
   aggat    2663   3.3 |    3815   0.5    4839   0.9    5549   1.1    8511   1.7   13127   2.3   17534   2.7   25378   3.3   22939   3.1   13783   2.4    9226   1.8
  gaggtc     508   3.2 |     448  -0.2     498  -0.0     525   0.0     917   0.9    1589   1.6    2083   2.0    3107   2.6    4803   3.2    4328   3.1    4820   3.2
  gagaac     635   3.2 |     614  -0.0     610  -0.1     598  -0.1     809   0.3    1171   0.9    1738   1.5    2688   2.1    3884   2.6    5820   3.2    5988   3.2
  aggaag     787   3.2 |    2466   1.6    3299   2.1    4517   2.5    4815   2.6    5632   2.8    7340   3.2    6939   3.1    6770   3.1    7365   3.2    3637   2.2
    aagg   11339   3.2 |   54187   2.3   72740   2.7  103708   3.2  105558   3.2  105227   3.2   96527   3.1   37230   1.7   14958   0.4   12115   0.1   10889  -0.1
  agggaa     702   3.2 |    1366   1.0    1568   1.2    1956   1.5    2131   1.6    2630   1.9    3486   2.3    4745   2.8    6514   3.2    5887   3.1    2922   2.1
  aggatt     807   3.2 |     835   0.0     945   0.2    1081   0.4    1482   0.9    2160   1.4    3235   2.0    5148   2.7    6993   3.1    7421   3.2    4793   2.6
   gggga    2366   3.2 |    4790   1.0    6076   1.4    9060   1.9   12565   2.4   14188   2.6   19902   3.1   21298   3.2   16319   2.8   11341   2.3    6375   1.4
  gagaat     796   3.2 |     765  -0.1     704  -0.2     630  -0.3     944   0.2    1458   0.9    2283   1.5    3709   2.2    5213   2.7    7144   3.2    6374   3.0
  aggtaa     706   3.1 |     934   0.4     855   0.3    1019   0.5    1411   1.0    1433   1.0    2275   1.7    4447   2.7    5624   3.0    6157   3.1    4822   2.8
  gggagc     607   3.1 |     667   0.1     838   0.5    1191   1.0    1729   1.5    2412   2.0    3647   2.6    5134   3.1    5259   3.1    4040   2.7    2242   1.9
   gagag    2060   3.1 |    6219   1.6    8204   2.0   10159   2.3   12731   2.6   13727   2.7   14715   2.8   17718   3.1   15764   2.9   14586   2.8    9288   2.2
  aggatc     457   3.1 |     423  -0.1     576   0.3     618   0.4     774   0.8    1206   1.4    1735   1.9    2910   2.7    3918   3.1    3399   2.9    2324   2.3
  aggacc     374   3.1 |     309  -0.3     376   0.0     483   0.4     611   0.7     852   1.2    1502   2.0    2046   2.5    2594   2.8    3196   3.1    1991   2.4
    aggt    8323   3.1 |   11750   0.5   13469   0.7   17182   1.0   29614   1.8   41922   2.3   55640   2.7   70685   3.1   45479   2.5   29428   1.8   14802   0.8
  ggggat     578   3.1 |     607   0.1     717   0.3     800   0.5    1239   1.1    1781   1.6    2421   2.1    4281   2.9    4762   3.0    4907   3.1    3570   2.6
  gagtaa     649   3.1 |    1032   0.7     770   0.2     911   0.5    1041   0.7     908   0.5    1471   1.2    2612   2.0    3240   2.3    3884   2.6    5493   3.1
  agggtg     516   3.1 |     401  -0.4     776   0.6     870   0.8     963   0.9    1915   1.9    2771   2.4    3214   2.6    4318   3.1    2160   2.1     924   0.8
  ggtgag     593   3.1 |     891   0.6    1184   1.0     991   0.7    1638   1.5    1804   1.6    1378   1.2    2676   2.2    3910   2.7    4027   2.8    4936   3.1
   gagac    1831   3.0 |    2103   0.2    1711  -0.1    2363   0.4    3400   0.9    4244   1.2    6994   1.9   10669   2.5   13149   2.8   15045   3.0   10148   2.5
  ggagcg     799   3.0 |     832   0.1     939   0.2    1253   0.6    2136   1.4    2799   1.8    3775   2.2    5774   2.9    6464   3.0    6564   3.0    5421   2.8
  gagaaa    1274   3.0 |    2556   1.0    2503   1.0    2254   0.8    2184   0.8    2504   1.0    3308   1.4    4802   1.9    8363   2.7   10426   3.0   10315   3.0
  aggact     393   3.0 |     409   0.1     444   0.2     572   0.5     718   0.9    1074   1.5    1592   2.0    2408   2.6    2846   2.9    3199   3.0    1965   2.3
   gagaa    3517   3.0 |    6294   0.8    5693   0.7    6466   0.9    7995   1.2    9554   1.4   13807   2.0   21533   2.6   28547   3.0   27588   3.0   17149   2.3
  gaggct     546   3.0 |     494  -0.1     534  -0.0     615   0.2     988   0.9    1546   1.5    2015   1.9    3242   2.6    4143   2.9    3547   2.7    4431   3.0
  gagacc     502   3.0 |     415  -0.3     396  -0.3     306  -0.7     506   0.0     751   0.6    1004   1.0    1670   1.7    2669   2.4    3293   2.7    4018   3.0
   aggac    1931   3.0 |    2531   0.4    3396   0.8    3704   0.9    5204   1.4    8356   2.1   10895   2.5   14361   2.9   15446   3.0    9163   2.2    8003   2.1
  agtagg     329   3.0 |     901   1.5    1411   2.1    1477   2.2    1690   2.4    2602   3.0    1807   2.5     878   1.4     729   1.1     661   1.0     622   0.9
  gagagt     425   3.0 |     518   0.3     615   0.5     595   0.5     957   1.2    1439   1.8    1951   2.2    2684   2.7    3285   3.0    3356   3.0    3106   2.9
   gaggc    2785   3.0 |    3023   0.1    3316   0.3    4416   0.7    7697   1.5    9725   1.8   13900   2.3   21791   3.0   17624   2.7   19552   2.8   13727   2.3
   aggta    2013   3.0 |    2233   0.1    3073   0.6    4019   1.0    4150   1.0    6240   1.6   10392   2.4   13101   2.7   15678   3.0   11741   2.5    7999   2.0
  gagact     346   2.9 |     319  -0.1     265  -0.4     230  -0.6     405   0.2     575   0.7     939   1.4    1613   2.2    1778   2.4    2313   2.7    2650   2.9
  tttagg     636   2.9 |    2150   1.8    3633   2.5    3829   2.6    3654   2.5    4831   2.9    2745   2.1     800   0.3     467  -0.4     440  -0.5     420  -0.6
  agaaag    1153   2.9 |    6379   2.5    8640   2.9    8047   2.8    6510   2.5    5678   2.3    3524   1.6    1950   0.8    1619   0.5    2160   0.9    2620   1.2
  gagatg     582   2.9 |     532  -0.1     878   0.6     778   0.4     800   0.5    1559   1.4    1989   1.8    2432   2.1    4303   2.9    2887   2.3    2600   2.2
    gaga   10005   2.9 |   18181   0.9   21929   1.1   28744   1.5   33654   1.8   44528   2.2   65132   2.7   72315   2.9   73556   2.9   46781   2.2   22681   1.2
  gagata     685   2.9 |     660  -0.1     765   0.2     813   0.2     783   0.2    1105   0.7    1738   1.3    2366   1.8    4154   2.6    4607   2.7    5033   2.9
  aggtag     392   2.9 |     571   0.5     611   0.6    1007   1.4    1488   1.9    1280   1.7    1640   2.1    2438   2.6    2201   2.5    2874   2.9    2397   2.6
  ggaata     826   2.9 |     856   0.1     896   0.1    1000   0.3     979   0.2    1141   0.5    1649   1.0    2458   1.6    3980   2.3    5724   2.8    6039   2.9
  aggtat     628   2.9 |     450  -0.5     511  -0.3     660   0.1     720   0.2     994   0.7    1519   1.3    2362   1.9    3676   2.5    4564   2.9    3027   2.3
  ggggta     415   2.9 |     446   0.1     616   0.6    1001   1.3     696   0.7    1004   1.3    1880   2.2    2444   2.6    3007   2.9    2885   2.8    2256   2.4
  attagg     465   2.8 |    1435   1.6    2591   2.5    2829   2.6    2652   2.5    3320   2.8    1997   2.1     701   0.6     421  -0.1     355  -0.4     381  -0.3
   ggggt    1914   2.8 |    2187   0.2    2675   0.5    2942   0.6    4918   1.4    7664   2.0   10018   2.4   13593   2.8    9509   2.3    7336   1.9    4288   1.2
  agtgag     433   2.8 |    1102   1.3    1601   1.9    1711   2.0    2799   2.7    3056   2.8    1882   2.1    2579   2.6    1876   2.1    1511   1.8    1555   1.8
  gagagc     538   2.8 |     588   0.1     609   0.2     596   0.1     776   0.5    1041   1.0    1418   1.4    2088   2.0    3043   2.5    3516   2.7    3773   2.8
  aacgga     608   2.8 |    1717   1.5    2376   2.0    3186   2.4    3794   2.6    4253   2.8    4047   2.7    2257   1.9     869   0.5     616   0.0     528  -0.2
    aggg    8388   2.8 |   22508   1.4   30924   1.9   42320   2.3   54019   2.7   54448   2.7   58393   2.8   47308   2.5   23365   1.5   18472   1.1   14193   0.8
  gagatt     756   2.8 |     668  -0.2     645  -0.2     599  -0.3     792   0.1    1162   0.6    1506   1.0    2752   1.9    4041   2.4    4602   2.6    5222   2.8
  aggacg     591   2.8 |     652   0.1     882   0.6    1328   1.2    1331   1.2    1759   1.6    2763   2.2    2873   2.3    3382   2.5    4008   2.8    2404   2.0
  gggaat     653   2.8 |     613  -0.1     545  -0.3     652  -0.0     878   0.4    1075   0.7    1478   1.2    2462   1.9    3515   2.4    4428   2.8    3430   2.4
  gagacg     536   2.8 |     645   0.3     796   0.6     644   0.3     777   0.5    1048   1.0    1103   1.0    1627   1.6    2581   2.3    3153   2.6    3629   2.8
  ggtagg     346   2.7 |     524   0.6     776   1.2     974   1.5    1546   2.2    2317   2.7    1142   1.7     922   1.4    1046   1.6     835   1.3     975   1.5
  aggtac     313   2.7 |     212  -0.6     256  -0.3     387   0.3     400   0.4     443   0.5     806   1.4    1145   1.9    1600   2.4    2083   2.7    1495   2.3
  gggata     571   2.7 |     570  -0.0     647   0.2     881   0.6     733   0.4    1068   0.9    1316   1.2    1724   1.6    2793   2.3    3621   2.7    3792   2.7
   gagtg    1673   2.7 |    1819   0.1    2669   0.7    3146   0.9    3406   1.0    6139   1.9    8549   2.4   10893   2.7   10998   2.7    8726   2.4    5650   1.8
  gggatt     650   2.7 |     542  -0.3     554  -0.2     543  -0.3     735   0.2     891   0.5    1176   0.9    1932   1.6    2639   2.0    3336   2.4    4272   2.7
  ggtgta     445   2.7 |     365  -0.3     394  -0.2     508   0.2     374  -0.3     449   0.0     732   0.7    1198   1.4    1660   1.9    2630   2.6    2921   2.7
  gagtgt     342   2.7 |     297  -0.2     270  -0.3     338  -0.0     515   0.6     712   1.1    1214   1.8    1764   2.4    2238   2.7    2018   2.6    1696   2.3
  ggaatc     589   2.7 |     511  -0.2     527  -0.2     463  -0.3     666   0.2     731   0.3     991   0.8    1687   1.5    2292   2.0    2694   2.2    3839   2.7
  gagggc     680   2.7 |     587  -0.2     669  -0.0     636  -0.1    1068   0.7    1863   1.5    2538   1.9    4430   2.7    4285   2.7    2677   2.0    3576   2.4
  ggaatt     888   2.7 |     769  -0.2     674  -0.4     611  -0.5     908   0.0    1042   0.2    1429   0.7    2569   1.5    3705   2.1    4792   2.4    5775   2.7
  ggataa     911   2.7 |    1374   0.6    1108   0.3    1119   0.3    1402   0.6    1127   0.3    1483   0.7    2596   1.5    2969   1.7    4809   2.4    5909   2.7
  gaggcg     961   2.7 |     833  -0.2    1165   0.3    1112   0.2    1468   0.6    2898   1.6    3294   1.8    4170   2.1    6230   2.7    4442   2.2    4914   2.4
  agggac     376   2.7 |     430   0.2     511   0.4     678   0.9     744   1.0     962   1.4    1505   2.0    1839   2.3    2415   2.7    2408   2.7    1435   1.9
    tagg    5882   2.7 |   14652   1.3   23992   2.0   25954   2.1   27835   2.2   37571   2.7   20770   1.8    8645   0.6    6332   0.1    5774  -0.0    6466   0.1
  aaagag    1207   2.7 |    3367   1.5    4744   2.0    5593   2.2    6944   2.5    7699   2.7    5738   2.2    4202   1.8    2405   1.0    1253   0.1    1214   0.0
  gagtag     355   2.7 |     664   0.9     676   0.9     728   1.0    1051   1.6     807   1.2     904   1.3    1316   1.9    1495   2.1    2013   2.5    2264   2.7
   ggaat    2936   2.7 |    3039   0.0    2985   0.0    3538   0.3    4255   0.5    5453   0.9    8355   1.5   12607   2.1   16459   2.5   18564   2.7   10288   1.8
    ggga    9227   2.6 |   19739   1.1   26873   1.5   36793   2.0   46224   2.3   51606   2.5   57901   2.6   54458   2.6   39822   2.1   24553   1.4   15287   0.7
   gagat    2607   2.6 |    2836   0.1    2573  -0.0    2941   0.2    4618   0.8    6129   1.2    9012   1.8   15212   2.5   14855   2.5   16337   2.6   10196   2.0
  gaggcc     833   2.6 |     571  -0.5     511  -0.7     556  -0.6     838   0.0    1349   0.7    1619   1.0    2557   1.6    5217   2.6    4498   2.4    4788   2.5
    gggg    9825   2.6 |   16393   0.7   22932   1.2   33282   1.8   43894   2.2   60448   2.6   59482   2.6   45307   2.2   35800   1.9   19393   1.0   11196   0.2
   agggt    1815   2.6 |    2119   0.2    2241   0.3    2491   0.5    3870   1.1    5944   1.7    7975   2.1   11109   2.6    7755   2.1    4647   1.4    4113   1.2
  ggaaac     822   2.6 |     902   0.1     710  -0.2     841   0.0     965   0.2    1079   0.4    1567   0.9    2425   1.6    2962   1.8    4766   2.5    5007   2.6
  ggaaat    1102   2.6 |    1031  -0.1     977  -0.2     949  -0.2    1201   0.1    1418   0.4    1935   0.8    3115   1.5    4335   2.0    6456   2.6    6674   2.6
  gagaag     852   2.6 |    1713   1.0    2477   1.5    2211   1.4    2529   1.6    2862   1.7    2225   1.4    2608   1.6    4073   2.3    5157   2.6    4911   2.5
  gggaaa     953   2.6 |    1510   0.7    1627   0.8    1532   0.7    1692   0.8    1767   0.9    2173   1.2    3228   1.8    4917   2.4    5747   2.6    4717   2.3
  ggtgac     654   2.6 |     515  -0.3     458  -0.5     404  -0.7     616  -0.1     533  -0.3     636  -0.0    1568   1.3    2318   1.8    2368   1.9    3917   2.6
  aggttt     880   2.6 |     650  -0.4     694  -0.3     757  -0.2     852  -0.0    1169   0.4    1829   1.1    2865   1.7    4394   2.3    5246   2.6    4491   2.4
  ggtgtt     655   2.6 |     441  -0.6     353  -0.9     354  -0.9     563  -0.2     492  -0.4     656   0.0    1588   1.3    2050   1.6    2850   2.1    3897   2.6
   gagta    1918   2.6 |    2142   0.2    2375   0.3    3022   0.7    2760   0.5    3783   1.0    6034   1.7    7911   2.0    9976   2.4   11370   2.6    8279   2.1
   gggaa    2853   2.5 |    4640   0.7    5021   0.8    5678   1.0    6420   1.2    7287   1.4    9751   1.8   13302   2.2   16578   2.5   13221   2.2    8159   1.5
  aggtta     596   2.5 |     605   0.0     703   0.2     856   0.5     668   0.2     974   0.7    1512   1.3    1896   1.7    3073   2.4    3457   2.5    2847   2.3
  taagag     570   2.5 |    1700   1.6    1589   1.5    2060   1.9    3289   2.5    2471   2.1    1900   1.7    2026   1.8     695   0.3     431  -0.4     553  -0.0
   ggaaa    4484   2.5 |    8274   0.9    8231   0.9    8786   1.0    8732   1.0    9130   1.0   12491   1.5   16293   1.9   24307   2.4   25647   2.5   14345   1.7
  ggaaaa    1729   2.5 |    2206   0.4    2145   0.3    2048   0.2    2303   0.4    2178   0.3    2788   0.7    4370   1.3    6216   1.8    9285   2.4    9886   2.5
  ggtggt     672   2.5 |     652  -0.0     639  -0.1     574  -0.2    1285   0.9    1583   1.2    1818   1.4    3145   2.2    2726   2.0    3006   2.2    3834   2.5
  gagcac     550   2.5 |     519  -0.1     391  -0.5     443  -0.3     525  -0.1     634   0.2     903   0.7    1139   1.1    1681   1.6    2791   2.3    3125   2.5
  aatgga     872   2.5 |    2031   1.2    2823   1.7    3206   1.9    4953   2.5    4162   2.3    3434   2.0    2697   1.6     885   0.0     559  -0.6     991   0.2
  agggta     431   2.5 |     451   0.1     588   0.4     683   0.7     597   0.5     699   0.7    1238   1.5    1693   2.0    2440   2.5    2019   2.2    1277   1.6
  attgga     679   2.5 |    1675   1.3    2260   1.7    2750   2.0    3839   2.5    3085   2.2    2843   2.1    2238   1.7     648  -0.1     387  -0.8     597  -0.2
    ggtg   10820   2.5 |    8293  -0.4   13790   0.3   13337   0.3   14561   0.4   29258   1.4   37124   1.8   42634   2.0   61173   2.5   29377   1.4   11268   0.1
   gaaag    3824   2.5 |   16976   2.2   20725   2.4   21461   2.5   19865   2.4   16394   2.1   10959   1.5    6836   0.8    5607   0.6    7472   1.0    8569   1.2
  gagtca     379   2.5 |     350  -0.1     327  -0.2     383   0.0     357  -0.1     440   0.2     577   0.6     853   1.2    1426   1.9    1676   2.1    2120   2.5
  gagttt     817   2.5 |     643  -0.3     614  -0.4     521  -0.6     706  -0.2     975   0.3    1283   0.7    1963   1.3    3067   1.9    3849   2.2    4565   2.5
   aggtt    2485   2.5 |    2354  -0.1    2765   0.2    2619   0.1    3881   0.6    5979   1.3    7687   1.6   12131   2.3   13818   2.5   11301   2.2   10313   2.1
  gagtcc     357   2.5 |     247  -0.5     233  -0.6     202  -0.8     251  -0.5     428   0.3     498   0.5     779   1.1    1282   1.8    1600   2.2    1952   2.5\
"""

if __name__ == "__main__":
	main(sys.argv[1], int(sys.argv[2]))

